@@ -88,7 +88,7 @@ class Recipe(zc.recipe.egg.Eggs):
 
         bindir = self.buildout['buildout']['bin-directory']
         for fn in MONGO_BINARIES:
-            fullname = os.path.join('dst', 'bin', fn)
+            fullname = os.path.join(dst, 'bin', fn)
             if os.path.exists(fullname):
                 shutil.copy(fullname, bindir)
 
